@@ -32,7 +32,7 @@ from django.db import models
 from django.db.models.fields import IntegerField
 from django.utils.text import capfirst
 from django.utils.translation import ugettext_lazy as _
-from dj.choices import unset, Choices
+from dj.choices import unset, Choices, Gender
 
 
 class ChoiceField(IntegerField):
@@ -40,6 +40,9 @@ class ChoiceField(IntegerField):
     __metaclass__ = models.SubfieldBase
 
     def __init__(self, *args, **kwargs):
+        if kwargs.get('_in_south'): # workaround for South removing `choices`
+            kwargs['choices'] = Gender
+            del kwargs['_in_south']
         if 'choices' not in kwargs:
             raise exceptions.ImproperlyConfigured("No choices class specified.")
         else:
@@ -83,7 +86,12 @@ class ChoiceField(IntegerField):
         return self.item_getter(value)[0]
 
     def get_prep_lookup(self, lookup_type, value):
-        value = self.get_prep_value(value)
+        if lookup_type == 'exact':
+            value = self.get_prep_value(value)
+        elif lookup_type in ('in', 'range'):
+            value = [self.get_prep_value(v) for v in value]
+        elif lookup_type != 'isnull':
+            raise TypeError('Invalid lookup_type: %r' % lookup_type)
         return super(ChoiceField, self).get_prep_lookup(lookup_type, value)
 
     def validate(self, value, model_instance):
@@ -123,6 +131,20 @@ class ChoiceField(IntegerField):
         value = self._get_val_from_obj(obj)
         return self.get_db_prep_value(value)
 
+    def south_field_triple(self):
+        kwargs = dict(
+            null=repr(self.null),
+            blank=repr(self.blank),
+            db_column=repr(self.db_column),
+            db_index=repr(self.db_index),
+            primary_key=repr(self.primary_key),
+            unique=repr(self.unique),
+            _in_south=repr(True),
+        )
+        if self.default is not models.NOT_PROVIDED:
+            kwargs['default'] = self.default
+        return ('dj.choices.fields.ChoiceField', [], kwargs)
+
 
 class _TypedChoiceField(forms.TypedChoiceField):
     def clean(self, value):
